@@ -7,11 +7,11 @@ def get_opts_count_virus(parser, sub_program):
 
 class Count_virus(Count_bam):
     """
-    Features
+    ## Features
 
-    - Count raw virus reads
+    - Taking the bam file as input, count the number of UMIs and reads mapped to the viral genome.
 
-    Output
+    ## Output
     - {sample_raw_read_count.json} : barcode - UMI - raw_reads_count
     """
 
